@@ -159,6 +159,9 @@ class Connection(object):
 
 
 class OvsdbIdl(idl.Idl):
+    def cooperative_yield(self):
+        time.sleep(0)
+
     @classmethod
     def from_server(cls, connection_string, schema_name):
         """Create the Idl instance by pulling the schema from OVSDB server"""
@@ -200,9 +203,13 @@ class OvsdbIdl(idl.Idl):
             self.cond_change(table, [False])
             del self.tables[table]
 
+        try:
+            _tables = idl.IdlTable.schema_tables(self, schema)
+        except AttributeError:
+            _tables = None
         # add new tables as Idl.__init__ does
         for table in (schema.tables[table] for table in added):
-            self.tables[table.name] = table
+            self.tables[table.name] = _tables[table.name] if _tables else table
             for column in table.columns.values():
                 if not hasattr(column, 'alert'):
                     column.alert = True
